@@ -177,3 +177,93 @@ STDLIBS = frozenset(
         "XML",
     )
 )
+
+
+## Token types gotten from: robot.parsing.lexer.tokens.Token
+
+
+SETTING_HEADER = "SETTING HEADER"
+VARIABLE_HEADER = "VARIABLE HEADER"
+TESTCASE_HEADER = "TESTCASE HEADER"
+KEYWORD_HEADER = "KEYWORD HEADER"
+COMMENT_HEADER = "COMMENT HEADER"
+
+TESTCASE_NAME = "TESTCASE NAME"
+KEYWORD_NAME = "KEYWORD NAME"
+
+DOCUMENTATION = "DOCUMENTATION"
+SUITE_SETUP = "SUITE SETUP"
+SUITE_TEARDOWN = "SUITE TEARDOWN"
+METADATA = "METADATA"
+TEST_SETUP = "TEST SETUP"
+TEST_TEARDOWN = "TEST TEARDOWN"
+TEST_TEMPLATE = "TEST TEMPLATE"
+TEST_TIMEOUT = "TEST TIMEOUT"
+FORCE_TAGS = "FORCE TAGS"
+DEFAULT_TAGS = "DEFAULT TAGS"
+LIBRARY = "LIBRARY"
+RESOURCE = "RESOURCE"
+VARIABLES = "VARIABLES"
+SETUP = "SETUP"
+TEARDOWN = "TEARDOWN"
+TEMPLATE = "TEMPLATE"
+TIMEOUT = "TIMEOUT"
+TAGS = "TAGS"
+ARGUMENTS = "ARGUMENTS"
+RETURN = "RETURN"
+
+NAME = "NAME"
+VARIABLE = "VARIABLE"
+ARGUMENT = "ARGUMENT"
+ASSIGN = "ASSIGN"
+KEYWORD = "KEYWORD"
+WITH_NAME = "WITH NAME"
+FOR = "FOR"
+FOR_SEPARATOR = "FOR SEPARATOR"
+END = "END"
+IF = "IF"
+ELSE_IF = "ELSE IF"
+ELSE = "ELSE"
+
+SEPARATOR = "SEPARATOR"
+COMMENT = "COMMENT"
+CONTINUATION = "CONTINUATION"
+EOL = "EOL"
+EOS = "EOS"
+
+ERROR = "ERROR"
+FATAL_ERROR = "FATAL ERROR"
+
+NON_DATA_TOKENS = frozenset((SEPARATOR, COMMENT, CONTINUATION, EOL, EOS))
+SETTING_TOKENS = frozenset(
+    (
+        DOCUMENTATION,
+        SUITE_SETUP,
+        SUITE_TEARDOWN,
+        METADATA,
+        TEST_SETUP,
+        TEST_TEARDOWN,
+        TEST_TEMPLATE,
+        TEST_TIMEOUT,
+        FORCE_TAGS,
+        DEFAULT_TAGS,
+        LIBRARY,
+        RESOURCE,
+        VARIABLES,
+        SETUP,
+        TEARDOWN,
+        TEMPLATE,
+        TIMEOUT,
+        TAGS,
+        ARGUMENTS,
+        RETURN,
+    )
+)
+HEADER_TOKENS = frozenset(
+    (SETTING_HEADER, VARIABLE_HEADER, TESTCASE_HEADER, KEYWORD_HEADER, COMMENT_HEADER)
+)
+ALLOW_VARIABLES = frozenset((NAME, ARGUMENT, TESTCASE_NAME, KEYWORD_NAME))
+
+CONTROL_TOKENS = frozenset(
+    (FOR, IF, ELSE, ELSE_IF, END, WITH_NAME, FOR_SEPARATOR, ASSIGN)
+)
